bayespy.inference.vmp.nodes.multinomial.MultinomialDistribution.random
======================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.multinomial

.. automethod:: MultinomialDistribution.random